/* -*- pse-c -*-
 *----------------------------------------------------------------------------
 * Filename: wdt.h
 * $Revision: 1.8 $
 * <Summary Description>
 *----------------------------------------------------------------------------
 *
 * Copyright (c) Intel Corporation (2002 - 2006).
 *
 * The source code contained or described herein and all documents
 * related to the source code ("Material") are owned by Intel
 * Corporation or its suppliers or licensors.  Title to the Material
 * remains with Intel Corporation or it suppliers and licensors.  The
 * Material contains trade secrets and proprietary and confidential 
 * information of Intel or its suppliers and licensors.  The Material is
 * protected by worldwide copyright and trade secret laws and
 * treaty provisions.  No part of the Material may be used, copied,
 * reproduced, modified, published, uploaded, posted, transmitted,
 * distributed, or disclosed in any way without Intels prior express
 * written permission.
 *
 * No license under any patent, copyright, trade secret or other
 * intellectual property right is granted to or conferred upon you by
 * disclosure or delivery of the Materials, either expressly, by
 * implication, inducement, estoppel or otherwise.  Any license
 * under such intellectual property rights must be express
 * and approved by Intel in writing.
 *
 *----------------------------------------------------------------------------
 *
 *  File Specification:
 *
 *  This file contains the common data defines required by both the WDT driver
 *  and applications that use the driver
 */

#ifndef _WDT_H_
#define _WDT_H_

#include <DEVIOCTL.H>


/*-----------------------------------------------------------------------------
 * SAWD1 is the name we pass to the CreateFile() function to get back a driver
 * handle
 *-----------------------------------------------------------------------------
 */

#define NT_DEVICE_NAME      L"\\Device\\SAWD0"     /* NT device name    */
#define WIN32_DEVICE_NAME_L L"\\DosDevices\\SAWD1" /* Win32 device name (WCHAR) */
#define WIN32_DEVICE_NAME   "\\\\.\\SAWD1"         /* Win32 device name for apps*/


/*----------------------------------------------------------------------
 * IOCTL Defines
 *----------------------------------------------------------------------
 */
#define IOCTL_GET_CAPABILITIES			\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x802,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

#define IOCTL_ENABLE_WDT			\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D00,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

#define IOCTL_DISABLE_WDT			\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D01,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

#define IOCTL_LOAD_COUNTER			\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D02,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

#define IOCTL_PING_THE_WDT 		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D03,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )
   
#define  IOCTL_SET_PRESCALAR		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D04,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

#define IOCTL_READ_DOWN_COUNTER 		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D05,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )
	
/* 0x0D06 is reserved for backwards compatibility (IOCTL_SET_WDT_INT_TYPE) */

#define IOCTL_SET_EXTERNAL_OUT		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D07,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

#define IOCTL_LOCK_DEVICE		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D08,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

#define IOCTL_ROUTE_INTERRUPT		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D09,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

/*  0x0D0A is reserved for backwards compatibility (IOCTL_WRITE_CONFIG) */

/*  0x0D0C is reserved for backwards compatibility (IOCTL_GETOBJECT_HANDLE) */

#define IOCTL_USER_HANDLE		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D0D,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

/*  0x0D0E is reserved for backwards compatibility (IOCTL_INTR_CONNECT) */

#define IOCTL_TEST_CALLBACK		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D0F,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

/*  0x0D10 is reserved for backwards compatibility (IOCTL_KILL_BUZZER)  */

/*  0x0D11 is reserved for backwards compatibility (IOCTL_IRQ_SEND_EOI) */

/*  0x0D12 is reserved for backwards compatibility (IOCTL_TEST_FEATURE) */

#define IOCTL_GET_STATUS		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D13,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

/*  0x0D14 is reserved for backwards compatibility (IOCTL_READ_PRELOAD) */

#define IOCTL_SET_MODE		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D15,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

#define IOCTL_GET_TIMEOUT_STATUS		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D16,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )

#define IOCTL_GET_STAGE_1_TIMEOUT_STATUS		\
	CTL_CODE( FILE_DEVICE_UNKNOWN, 0x0D17,	\
		METHOD_BUFFERED, FILE_ANY_ACCESS )


/*-----------------------------------------------------------------------------
 * Structure used by the IOCTL code to return capabiltity information to
 * the caller
 *-----------------------------------------------------------------------------
 */

typedef struct _SAWD_CAPABILITY_OUT_BUFF {
    
    unsigned long       Version;    // version of interface used
	unsigned long	    min;		// minimum value in msecs
	unsigned long	    max;		// maximum value in msecs

} SAWD_CAPABILITY_OUT_BUFF, *PSAWD_CAPABILITY_OUT_BUFF;



/*-----------------------------------------------------------------------------
 * Structure used by the IOCTL code to return register information to
 * the caller
 *-----------------------------------------------------------------------------
 */

typedef struct _SAWD_CTRL {

	HANDLE             UserEvent;      /* Handle to a Ring 3 user event */
	unsigned long      Version;        /* version of interface used     */
	unsigned long      Flags;          /* flags defined below */
	unsigned long      Preload1;       /* Preload register # 1 */
	unsigned long      Preload2;       /* Preload Register # 2 */
	unsigned long      DownCount;      /* Holds current down count */
	unsigned long      ConfigReg;      /* 16 bit Configuation register */
	unsigned short     DeviceStatus;   /* store device status bits */
	unsigned short     ReloadReg;      /* 16 bit reload register */
	unsigned short     LockReg;        /* 8 bit Lock register */
	unsigned long      InterruptCount; /* # of times stage 1 INT has occured */

	unsigned short     IRQ;
	short              BusType;
	unsigned short     BusNumber;

	unsigned short      IrqOffset;

} SAWD_CTRL, *PSAWD_CTRL;



/*-----------------------------------------------------------------------------
 * Types of interrupt stage 1 can trigger
 *-----------------------------------------------------------------------------
 */
#define WDT_INTR_PCI        0x00  /* SERIRQ (Default) */
#define WDT_INTR_NMI        0x01  /* NMI */
#define WDT_INTR_SMI        0x02  /* SMI */
#define WDT_INTR_DIS        0x03  /* Disabled */

#endif

/*-----------------------------------------------------------------------------
 * $Id: wdt.h,v 1.8 2006/01/13 23:53:24 syeh2 Exp $
 * $Source: /nfs/fm/proj/eia/cvsroot/drivers/WhitmoreLake/Windows/WDT/include/wdt.h,v $
 *-----------------------------------------------------------------------------
 */
